==> everylint-1.0.0.tar.gz: README.md <==
# EveryLint



This package enables [all the linters][0] that are flagged with 
[![pedantic](https://dart-lang.github.io/linter/lints/style-pedantic.svg)](https://github.com/dart-lang/pedantic/#enabled-lints)
[![flutter](https://dart-lang.github.io/linter/lints/style-flutter.svg)](https://github.com/flutter/flutter/blob/master/packages/flutter/lib/analysis_options_user.yaml)
[![effective dart](https://dart-lang.github.io/linter/lints/style-effective_dart.svg)](https://github.com/tenhobi/effective_dart) and some additional ones

## Additional linters

```
avoid_returning_null_for_future
invariant_booleans
iterable_contains_unrelated_type
list_remove_unrelated_type
literal_only_boolean_expressions
prefer_void_to_null
always_put_control_body_on_new_line
avoid_as
avoid_bool_literals_in_conditional_expressions
avoid_field_initializers_in_const_classes
avoid_function_literals_in_foreach_calls
avoid_renaming_method_parameters
avoid_single_cascade_in_expression_statements
avoid_unnecessary_containers
avoid_unused_constructor_parameters
avoid_void_async
leading_newlines_in_multiline_strings
parameter_assignments
prefer_asserts_``in_initializer_lists
prefer_collection_literals
prefer_conditional_assignment
prefer_const_constructors
prefer_const_constructors_in_immutables
prefer_const_declarations
prefer_foreach
prefer_if_elements_to_conditional_expressions
prefer_inlined_adds
prefer_is_not_operator
prefer_null_aware_operators
prefer_typing_uninitialized_variables
sized_box_for_whitespace
slash_for_doc_comments
unnecessary_null_aware_assignments
unnecessary_overrides
unnecessary_parenthesis
unnecessary_raw_strings
unnecessary_string_escapes
unnecessary_string_interpolations
use_is_even_rather_than_modulo
use_string_buffers
use_to_and_as_if_applicable
void_checks
sort_pub_dependencies

```

==> everylint-1.0.2.tar.gz: README.md <==
# EveryLint



This package enables [all the linters][0] that are flagged with 
[![pedantic](https://dart-lang.github.io/linter/lints/style-pedantic.svg)](https://github.com/dart-lang/pedantic/#enabled-lints)
[![flutter](https://dart-lang.github.io/linter/lints/style-flutter.svg)](https://github.com/flutter/flutter/blob/master/packages/flutter/lib/analysis_options_user.yaml)
[![effective dart](https://dart-lang.github.io/linter/lints/style-effective_dart.svg)](https://github.com/tenhobi/effective_dart) and some additional ones

[0]: https://dart-lang.github.io/linter/lints/

## Additional linters

```
avoid_returning_null_for_future
invariant_booleans
iterable_contains_unrelated_type
list_remove_unrelated_type
literal_only_boolean_expressions
prefer_void_to_null
always_put_control_body_on_new_line
avoid_as
avoid_bool_literals_in_conditional_expressions
avoid_field_initializers_in_const_classes
avoid_function_literals_in_foreach_calls
avoid_renaming_method_parameters
avoid_single_cascade_in_expression_statements
avoid_unnecessary_containers
avoid_unused_constructor_parameters
avoid_void_async
leading_newlines_in_multiline_strings
parameter_assignments
prefer_asserts_in_initializer_lists
prefer_collection_literals
prefer_conditional_assignment
prefer_const_constructors
prefer_const_constructors_in_immutables
prefer_const_declarations
prefer_foreach
prefer_if_elements_to_conditional_expressions
prefer_inlined_adds
prefer_is_not_operator
prefer_null_aware_operators
prefer_typing_uninitialized_variables
sized_box_for_whitespace
slash_for_doc_comments
unnecessary_null_aware_assignments
unnecessary_overrides
unnecessary_parenthesis
unnecessary_raw_strings
unnecessary_string_escapes
unnecessary_string_interpolations
use_is_even_rather_than_modulo
use_string_buffers
use_to_and_as_if_applicable
void_checks
sort_pub_dependencies

```
